Package: sendmailR
Version: 1.4-1
Title: Send Email Using R
Description: Package contains a simple SMTP client with minimal dependencies which 
        provides a portable solution for sending email, including file attachments and inline html reports, 
        from within R. SMTP Authentication and SSL/STARTTLS is implemented using curl.
Authors@R: c(
        person("Olaf", "Mersmann", role=c("aut", "cre"),
               comment = c(ORCID = "0000-0002-7720-4939"),
               email = "olafm@p-value.net"),
        person("Quinn", "Weber", role="ctb"),
        person("Marius", "Barth", role = "ctb",
               comment = c(ORCID = "0000-0002-3421-6665")),
        person("Are", "Edvardsen", role = "ctb",
               comment = c(ORCID = "0000-0002-5210-3656")),
        person("Alexander", "Bartel", role = "ctb", 
               comment = c(ORCID = "0000-0002-1280-6138"))
        )
URL: https://github.com/olafmersmann/sendmailR
BugReports: https://github.com/olafmersmann/sendmailR/issues
Depends: R (>= 3.0.0)
Imports: base64enc
Suggests: curl (>= 4.0), knitr, rmarkdown, htmltools
License: GPL-2
Encoding: UTF-8
RoxygenNote: 7.3.3
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-04-11 23:21:46 UTC; olafm
Author: Olaf Mersmann [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-7720-4939>),
  Quinn Weber [ctb],
  Marius Barth [ctb] (ORCID: <https://orcid.org/0000-0002-3421-6665>),
  Are Edvardsen [ctb] (ORCID: <https://orcid.org/0000-0002-5210-3656>),
  Alexander Bartel [ctb] (ORCID: <https://orcid.org/0000-0002-1280-6138>)
Maintainer: Olaf Mersmann <olafm@p-value.net>
Repository: CRAN
Date/Publication: 2026-04-12 05:10:02 UTC
Built: R 4.6.0; ; 2026-04-26 12:18:07 UTC; unix
