# Generated by roxygen2: do not edit by hand

S3method(mime_part,character)
S3method(mime_part,data.frame)
S3method(mime_part,default)
S3method(mime_part,ggplot)
S3method(mime_part,matrix)
S3method(mime_part,trellis)
export(mime_part)
export(mime_part_html)
export(sendmail)
export(sendmailOptions)
export(sendmail_options)
importFrom(base64enc,base64encode)
importFrom(grDevices,pdf)
